// Copyright 2004, 2005 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.hivemind.schema.rules;

import org.apache.hivemind.Location;
import org.apache.hivemind.internal.Module;
import org.apache.hivemind.schema.Translator;
import org.apache.hivemind.util.IdUtils;

/**
 * A {@link org.apache.hivemind.schema.Translator} that acts as a wrapper around the
 * {@link org.apache.hivemind.util.IdUtils#qualify(String, String)} method.
 * 
 * @author Howard Lewis Ship
 */
public class QualifiedIdTranslator implements Translator
{
    /**
     * @return null if the inputValue is null, otherwise, invokes
     *         {@link IdUtils#qualify(String, String)}.
     */
    public Object translate(Module contributingModule, Class propertyType, String inputValue,
            Location location)
    {
        if (inputValue == null)
            return null;

        return IdUtils.qualify(contributingModule.getModuleId(), inputValue);
    }

}